# oid_translate

### Description

This is a light wrapper around a C library (netsnmp) to allow quick translations between OID and MIB Names in Python.

### Installation

New versions will be updated to PyPI pretty regularly so it should be as easy
as:

```bash
pip install oid_translate
```
